@@ -1,5 +1,5 @@
 #' R6 Class - Generate Sphere Geometry
-#'
+#' @author Zhengjia Wang
 #' @name SphereGeom
 NULL
 
@@ -19,31 +19,6 @@ SphereGeom <- R6::R6Class(
     width_segments = 10,
     height_segments = 6,
 
-    # will be used to calculate Color of sphere, can be a single value or a vector (timestamp)
-    value = NULL,
-
-    set_value = function(value = NULL, time_stamp = NULL){
-
-      # Check length
-      if(length(value) > 1){
-        stopifnot2(length(value) == length(time_stamp), msg = 'Please specify time stamp for each color. They should share the same length.')
-      }else{
-        if(length(value) == 0){
-          time_stamp = NULL
-          value = NULL
-        }else if (length(time_stamp) != 1){
-          time_stamp = 0
-        }
-      }
-
-      stopifnot2(length(time_stamp) == 0 || is.numeric(time_stamp),
-                msg = 'time_stamp must be numerical values.')
-
-      self$value = value
-
-      self$time_stamp = time_stamp
-    },
-
     initialize = function(name, position = c(0,0,0), radius = 5, ...){
       super$initialize(name, position = position, ...)
 
@@ -55,7 +30,8 @@ SphereGeom <- R6::R6Class(
 
       self$set_value(
         value = get2('value', other_args, ifnotfound = NULL),
-        time_stamp = get2('time_stamp', other_args, ifnotfound = NULL)
+        time_stamp = get2('time_stamp', other_args, ifnotfound = NULL),
+        name = get2('name', other_args, ifnotfound = 'default')
       )
 
     },
